;+
; NAME:
;       SPI_Read_0BData
;
; PURPOSE:
;       Read a SPICAM/V 0B (IR) data file.
;       From Read_Record procedure without geo part, 
;       contained in SPICAMIRCALIBRATION_NEWARCHIVE_AUTO_2012 procedure (IKI),
;       (mail Anna Fedorova 28/11/2012)
;       
;       "-----------------------------------
;       DESCRIPTION:
;         this routine read all IR spectra from a binary file
;         the binary file contains :
;         - 17 command parameters
;         - 4 numbers : ExpectedPoints, NumberofSpectra, NumberofSessions, Channels
;         - frequency array
;         and for each spectrum :
;         - time + 6 system monitor's values
;         - a spectrum - detector 1
;         - a spectrum - detector 2
;        -----------------------------------"
;
; CALLING SEQUENCE:
;       Result = SPI_Read_0BData(Filename)
;
; INPUTS:
;       Filename = String containing the full data file name.
;
; OUTPUTS:
;       Result = Structure with sub-structures:
;           - HEADER
;           - FREQUENCY
;           - INFOSERV
;           - TIME
;           - TIME_C
;           - SPECTRARR1
;           - SPECTRARR2
;           - FREQARRAY
;
; AUTHOR:
;   Gaetan Lacombe
;     CNRS | LATMOS - Laboratoire Atmospheres, Milieux, Observations Spatiales.
;     11 boulevard d'Alembert
;     78280 Guyancourt
;     France
;     Tel. 33-(0) 1 80 28 50 57
;     Email. gaetan.lacombe@latmos.ipsl.fr
;
; SVN revision information:
;       $Rev: 2280 $
;       $Author: lacombe $
;       $Date: 2014-09-26 14:17:39 +0200 (Ven, 26 sep 2014) $
;

FUNCTION SPI_Read_Data0B,fname_data

   ;--- Check instrument name 
   str_instr = (strsplit(file_basename(fname_data),'_',/EXTRACT))[0]
   
   IF stregex(str_instr, 'SPIM') NE -1 THEN BEGIN
     spim_read_dataheader_IR, fname_data, time_start, time_end, INFOSPEC, INFOSERV, COMMAND, $
                              Header, InfoServArray, TimeArray, Time_c, SpectrArr1, SpectrArr2, FreqArray
   ENDIF ELSE  IF stregex(str_instr, 'SPIV') NE -1 THEN BEGIN
     spiv_read_dataheader_IR, fname_data, time_start, time_end, INFOSPEC, NumberofSpectra, NumberofSessions, $
                             ExpectedPoints, Channels, COMMAND, Header, InfoServArray, TimeArray, Time_c, SpectrArr1, SpectrArr2, FreqArray
   ENDIF ELSE BEGIN
    print,'Input file is not a SPICAM/SPICAV file'
    return,0
   ENDELSE
                              
    ;--- Build obs. info struct
    strarr_NameElements = StRegEx(fname_data,'_(([0-9]{4,5})|([CPN][0-9]{3}))A[0-9]{2}_[A-Z]_',/EXTRACT)
    Orbit = Fix(StRegEx(strarr_NameElements,'[0-9]{3,5}',/EXTRACT))
    
    str_Seq = StRegEx(strarr_NameElements,'A[0-9]{2}_',/EXTRACT)
    seq = Fix(StRegEx(str_Seq,'[0-9]{2}',/EXTRACT))
    
    str_ObsType = StRegEx(strarr_NameElements,'_[A-Z]_',/EXTRACT)
    ObsType = StRegEx(str_ObsType,'[A-Z]',/EXTRACT)
    
    INFOBS = {  Orbit:Orbit     ,$
                Seq:seq         ,$
                ObsType: ObsType }
                
    ;--- Building the output structure ---
    struc_DataFile = { Header:Header            , $
                       COMMAND:COMMAND          , $
                       INFOBS: INFOBS           , $
                       INFOSERV:InfoServArray   , $
                       INFOSPEC: INFOSPEC       , $
                       TIME:TimeArray           , $
                       TIME_C:Time_c            , $
                       SPECTRARR1:SpectrArr1    , $
                       SPECTRARR2:SpectrArr2    , $
                       FreqArray:FreqArray      }
                       
    return,struc_DataFile

END
